@@ -25,4 +25,5 @@ class A20OLinuXinoLime2ImageBuilder(A20ImageBuilder):
     """Image builder for A20 OLinuXino Lime2 targets."""
     machine = 'a20-olinuxino-lime2'
     flash_kernel_name = 'Olimex A20-OLinuXino-LIME2'
-    u_boot_path = 'usr/lib/u-boot/A20-OLinuXino-Lime2/u-boot-sunxi-with-spl.bin'
+    u_boot_path = \
+        'usr/lib/u-boot/A20-OLinuXino-Lime2/u-boot-sunxi-with-spl.bin'
