@@ -32,7 +32,6 @@ from .. import library
 
 class TestLibrary(unittest.TestCase):
     """Test all internal library methods used for building image."""
-
     def setUp(self):
         """Common setup for each test."""
         self.args = ['1', '2', '3']
@@ -319,8 +318,10 @@ modify x x
             self.state['mount_point'] + '/boot/firmware'
         ])
 
-        library.mount_filesystem(
-            self.state, '/dev/pts', 'dev/pts', is_bind_mount=True)
+        library.mount_filesystem(self.state,
+                                 '/dev/pts',
+                                 'dev/pts',
+                                 is_bind_mount=True)
         run.assert_called_with([
             'mount', '/dev/pts', self.state['mount_point'] + '/dev/pts', '-o',
             'bind'
@@ -452,8 +453,7 @@ modify x x
             [[library.qemu_remove_binary, (self.state, ), {}],
              [
                  library.unmount_filesystem,
-                 (None, self.state['mount_point'] + '/etc/machine-id'),
-                 {
+                 (None, self.state['mount_point'] + '/etc/machine-id'), {
                      'ignore_fail': True
                  }
              ]])
@@ -483,6 +483,13 @@ modify x x
         library.install_package(self.state, 'nmap')
         run.assert_called_with(self.state,
                                ['apt-get', 'install', '-y', 'nmap'])
+        library.install_package(self.state,
+                                'freedombox',
+                                install_from_backports=True)
+        run.assert_called_with(self.state, [
+            'find', '.', '-maxdepth', '1', '-iname', '"freedombox*.deb"',
+            '-delete'
+        ])
 
     @patch('freedommaker.library.install_package')
     @patch('freedommaker.library.run_in_chroot')
@@ -542,8 +549,11 @@ ff02::2 ip6-allrouters
         get_uuid.return_value = 'root-uuid'
         with self.assert_file_change(fstab_path, 'initial-trash',
                                      expected_content):
-            library.add_fstab_entry(
-                self.state, 'root', 'btrfs', 1, append=False)
+            library.add_fstab_entry(self.state,
+                                    'root',
+                                    'btrfs',
+                                    1,
+                                    append=False)
 
         expected_content += 'UUID=boot-uuid /boot ext4 errors=remount-ro 0 2\n'
         get_uuid.return_value = 'boot-uuid'
