@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 Tests for checking built image with VirtualBox.
 """
@@ -32,7 +31,6 @@ logger = logging.getLogger(__name__)
 
 class TestVirtualBox(unittest.TestCase):
     """Tests for checking built image with VirtualBox."""
-
     def setUp(self):
         """Setup test case."""
         self.path = os.path.dirname(__file__)
@@ -44,8 +42,8 @@ class TestVirtualBox(unittest.TestCase):
 
     def random_string(self):
         """Generate a random string."""
-        return ''.join([random.choice(string.ascii_lowercase)
-                        for _ in range(8)])
+        return ''.join(
+            [random.choice(string.ascii_lowercase) for _ in range(8)])
 
     def invoke(self, targets=None, **kwargs):
         """Invoke Freedom Maker."""
@@ -74,8 +72,8 @@ class TestVirtualBox(unittest.TestCase):
         """Execute a command."""
         subprocess.check_call(*args)
 
-    @unittest.skipUnless(os.environ.get('FM_RUN_VM_TESTS') == 'true',
-                         'Not requested')
+    @unittest.skipUnless(
+        os.environ.get('FM_RUN_VM_TESTS') == 'true', 'Not requested')
     def test_basic_build(self):
         """Test booting and opening SSH shell.
 
@@ -92,41 +90,45 @@ class TestVirtualBox(unittest.TestCase):
         built_file = compressed_built_file.rsplit('.', maxsplit=1)[0]
 
         if not os.path.isfile(built_file):
-            subprocess.check_call(['unxz', '--keep', '--force',
-                                   compressed_built_file])
+            subprocess.check_call(
+                ['unxz', '--keep', '--force', compressed_built_file])
 
         passwd_tool = os.path.join(self.path, '..', '..', 'bin',
                                    'passwd-in-image')
-        self._run(
-            ['sudo', 'python3', passwd_tool, built_file, 'fbx', '--password',
-             'frdm'])
+        self._run([
+            'sudo', 'python3', passwd_tool, built_file, 'fbx', '--password',
+            'frdm'
+        ])
         try:
-            self._run(
-                ['VBoxManage', 'createvm', '--name', vm_name, '--ostype',
-                 'Debian', '--register'])
-            self._run(
-                ['VBoxManage', 'storagectl', vm_name, '--name',
-                 'SATA Controller', '--add', 'sata', '--controller',
-                 'IntelAHCI'])
-            self._run(
-                ['VBoxManage', 'storageattach', vm_name, '--storagectl',
-                 'SATA Controller', '--port', '0', '--device', '0', '--type',
-                 'hdd', '--medium', built_file])
-            self._run(
-                ['VBoxManage', 'modifyvm', vm_name, '--pae', 'on', '--memory',
-                 '1024', '--vram', '128', '--nic1', 'nat', '--natpf1',
-                 ',tcp,,{port},,22'.format(port=test_ssh_port)])
-            self._run(
-                ['VBoxManage', 'startvm', vm_name, '--type', 'headless'])
+            self._run([
+                'VBoxManage', 'createvm', '--name', vm_name, '--ostype',
+                'Debian', '--register'
+            ])
+            self._run([
+                'VBoxManage', 'storagectl', vm_name, '--name',
+                'SATA Controller', '--add', 'sata', '--controller', 'IntelAHCI'
+            ])
+            self._run([
+                'VBoxManage', 'storageattach', vm_name, '--storagectl',
+                'SATA Controller', '--port', '0', '--device', '0', '--type',
+                'hdd', '--medium', built_file
+            ])
+            self._run([
+                'VBoxManage', 'modifyvm', vm_name, '--pae', 'on', '--memory',
+                '1024', '--vram', '128', '--nic1', 'nat', '--natpf1',
+                ',tcp,,{port},,22'.format(port=test_ssh_port)
+            ])
+            self._run(['VBoxManage', 'startvm', vm_name, '--type', 'headless'])
             time.sleep(first_run_wait_time)
 
             echo = subprocess.Popen(['echo', 'frdm'], stdout=subprocess.PIPE)
-            process = subprocess.Popen(
-                ['sshpass', '-p', 'frdm', 'ssh',
-                 '-o', 'UserKnownHostsFile=/dev/null',
-                 '-o', 'StrictHostKeyChecking=no',
-                 '-t', '-t', '-p', str(test_ssh_port), 'fbx@127.0.0.1',
-                 'sudo plinth --diagnose'], stdin=echo.stdout)
+            process = subprocess.Popen([
+                'sshpass', '-p', 'frdm', 'ssh', '-o',
+                'UserKnownHostsFile=/dev/null', '-o',
+                'StrictHostKeyChecking=no', '-t', '-t', '-p',
+                str(test_ssh_port), 'fbx@127.0.0.1', 'sudo plinth --diagnose'
+            ],
+                                       stdin=echo.stdout)
             process.communicate()
         finally:
             self._run(['VBoxManage', 'controlvm', vm_name, 'poweroff'])
